@@ -7,36 +7,50 @@
 import requests
 import json
 from datetime import datetime
+from typing import (
+    Dict, Any
+)
+from pydantic import (
+   BaseModel, Field, validator
+)
 
 from wpy.functools import clock
 
 from wush.common.constants import Constants
 from wush.common.loggers import get_logger
 from wush.common.run_mode import RunMode
-from wush.config.models import RequestModel
 from wush.web.curl_utils import cUrl
-from wush.web.cookie import Cookie
 from wush.web.enums import MethodEnum
 from wush.web.enums import RequestsParamsEnum
 from wush.web.response import ResponseClient
-from wush.model import Model
-from wush.model import datatype
+from csarg.parser import Argument
 
+__all__ = ['RequestBuilder']
 
-class RequestBuilder(Model):
+def create_version() -> str:
+    return datetime.now().strftime('%Y%m%d%H%M%S_%s')
+
+class RequestBuilder(BaseModel):
     """请求构造器"""
-    logger = get_logger('RequestBuilder')
-    version = datatype.Str()
-    method = datatype.Str(enum=MethodEnum, default=MethodEnum.GET.value,
-        upper=True)                     # 请求方式
-    url = datatype.Str()                # 地址
-    params = datatype.Dict()            # get 请求参数
-    json = datatype.Dict()              # post 请求参数
-    body = datatype.Str()               # body 请求参数
-    headers = datatype.Dict()           # headers 请求参数
-    cookies = datatype.Dict()           # cookies 请求参数
-    run_mode = datatype.Object(model = RunMode)             # 运行模式
-    argument = datatype.Object()  # 参数解析器
+    version: str = Field(title="版本号", default_factory = create_version)
+    url: str = Field(..., title="地址")
+    method: str = Field(MethodEnum.GET.value, title="请求方式")
+    params: Dict[str, Any] = Field({}, title="地址参数")
+    json_data: Dict[str, Any] = Field({}, title="json 参数", alias="json")
+    body: str = Field(None, title="body 参数")
+    headers: Dict[str, Any] = Field({}, title="headers 参数")
+    cookies: Dict[str, Any] = Field({}, title="cookies 参数")
+    run_mode: RunMode = Field(None, title="运行模式")
+    argument: Argument = Field(None, title="参数解析器")
+
+    class Config:
+        arbitrary_types_allowed = True
+
+    @validator('method')
+    def check_and_format_method(cls, v: str) -> str:
+        v = v.upper()
+        MethodEnum.validate(v)
+        return v
 
     @classmethod
     def load_curl(cls, curl_file):
@@ -46,32 +60,6 @@ class RequestBuilder(Model):
         ins.format()
         return
 
-    @classmethod
-    def loads_request_model(cls, request_model: RequestModel,
-            with_browser_cookie=False):
-        """加载 RequestModel 模型"""
-        ins = cls()
-        #  request_model.format()
-        request_dict = request_model.to_dict()
-        for key in RequestsParamsEnum.values():
-            #  val = getattr(request_model, key)
-            #  if key in ('params', 'json'):
-                #  val = val.to_dict()
-            val = request_dict.get(key)
-            setattr(ins, key, val)
-
-        request_cookies = {}
-        # 对 cookie_domains 进行解析
-        cookie_domains = request_model.cookie_domains
-        if cookie_domains and with_browser_cookie:
-            cookies  = Cookie.get_browser_cookie(*cookie_domains)
-            request_cookies.update(cookies)
-        request_cookies.update(ins.cookies)
-        ins.cookies = request_cookies
-
-        ins.format()
-        return ins
-
     def add_headers(self, **kwargs):
         """添加 headers"""
         self.headers.update(kwargs)
@@ -91,14 +79,11 @@ class RequestBuilder(Model):
                 data[key] = getattr(self, key)
             except:
                 pass
+        data['json'] = self.json_data
         return data
 
-    def format(self):
-        self.version = datetime.now().strftime('%Y%m%d%H%M%S_%s')
-        super().format()
 
-
-class RequestClient(object):
+class RequestClient:
     """请求客户端"""
     logger = get_logger('RequestClient')
 
@@ -108,7 +93,7 @@ class RequestClient(object):
     def request(self):
         """发送请求"""
         params = self.builder.to_requests()
-        self.logger.info('request builder %s', json.dumps(params, indent=4))
+        self.logger.info(f'request builder {json.dumps(params, indent=4)}')
         res = self._request(**params)
         res_client = ResponseClient(self.builder, res)
         if res_client.status_code in (301, 302):
@@ -121,3 +106,4 @@ class RequestClient(object):
     @clock(fmt = Constants.CLOCK_FMT, logger_func = logger.info)
     def _request(self, **params):
         return requests.request(**params)
+
